@@ -93,7 +93,7 @@ fn create_cast(from: &QualifiedName, to: &QualifiedName, mutable: CastMutability
         name: ApiName::new_from_qualified_name(name),
         fun: Box::new(crate::conversion::api::FuncToConvert {
             ident,
-            doc_attr: None,
+            doc_attrs: Vec::new(),
             inputs: [fnarg].into_iter().collect(),
             output: parse_quote! {
                 -> * #return_mutability #to_typ
