@@ -9,7 +9,7 @@
 use std::{collections::HashSet, fmt::Display};
 
 use crate::types::{make_ident, Namespace, QualifiedName};
-use autocxx_parser::{RustFun, RustPath};
+use autocxx_parser::{ExternCppType, RustFun, RustPath};
 use itertools::Itertools;
 use quote::ToTokens;
 use syn::{
@@ -17,13 +17,16 @@ use syn::{
     punctuated::Punctuated,
     token::{Comma, Unsafe},
     Attribute, FnArg, Ident, ItemConst, ItemEnum, ItemStruct, ItemType, ItemUse, LitBool, LitInt,
-    Pat, ReturnType, Type, TypePath, Visibility,
+    Pat, ReturnType, Type, Visibility,
 };
 
 use super::{
-    analysis::fun::{
-        function_wrapper::{CppFunction, CppFunctionBody, CppFunctionKind},
-        ReceiverMutability,
+    analysis::{
+        fun::{
+            function_wrapper::{CppFunction, CppFunctionBody, CppFunctionKind},
+            ReceiverMutability,
+        },
+        PointerTreatment,
     },
     convert_error::{ConvertErrorWithContext, ErrorContext},
     ConvertError,
@@ -152,6 +155,24 @@ impl References {
             ..Default::default()
         }
     }
+    pub(crate) fn param_treatment(&self, param: &Ident) -> PointerTreatment {
+        if self.rvalue_ref_params.contains(param) {
+            PointerTreatment::RValueReference
+        } else if self.ref_params.contains(param) {
+            PointerTreatment::Reference
+        } else {
+            PointerTreatment::Pointer
+        }
+    }
+    pub(crate) fn return_treatment(&self) -> PointerTreatment {
+        if self.rvalue_ref_return {
+            PointerTreatment::RValueReference
+        } else if self.ref_return {
+            PointerTreatment::Reference
+        } else {
+            PointerTreatment::Pointer
+        }
+    }
 }
 
 #[derive(Clone)]
@@ -514,7 +535,7 @@ pub(crate) enum Api<T: AnalysisPhase> {
     /// and so-forth by referring to some definition elsewhere.
     ExternCppType {
         name: ApiName,
-        rust_path: TypePath,
+        details: ExternCppType,
         pod: bool,
     },
 }
